"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUnityReleases = exports.UnityReleaseStream = void 0;
const unityChangeset_js_1 = require("./unityChangeset.js");
const graphql_request_1 = require("graphql-request");
const UNITY_GRAPHQL_ENDPOINT = "https://services.unity.com/graphql";
var UnityReleaseStream;
(function (UnityReleaseStream) {
    UnityReleaseStream["LTS"] = "LTS";
    UnityReleaseStream["TECH"] = "TECH";
    UnityReleaseStream["BETA"] = "BETA";
    UnityReleaseStream["ALPHA"] = "ALPHA";
})(UnityReleaseStream || (exports.UnityReleaseStream = UnityReleaseStream = {}));
async function getUnityReleases(version, stream = []) {
    const client = new graphql_request_1.GraphQLClient(UNITY_GRAPHQL_ENDPOINT);
    const query = (0, graphql_request_1.gql) `
query GetRelease($limit: Int, $skip: Int, $version: String!, $stream: [UnityReleaseStream!])
{
  getUnityReleases(
    limit: $limit
    skip: $skip
    stream: $stream
    version: $version
    entitlements: []
  ) {
    totalCount
    edges {
      node {
        version
        shortRevision
      }
    }
    pageInfo {
      hasNextPage
    }
  }
}
`;
    const variables = {
        limit: 1000,
        skip: 0,
        version: version,
        stream: stream,
    };
    const results = [];
    while (true) {
        const data = await client.request(query, variables);
        results.push(...data.getUnityReleases.edges.map((edge) => new unityChangeset_js_1.UnityChangeset(edge.node.version, edge.node.shortRevision)));
        if (data.getUnityReleases.pageInfo.hasNextPage === false) {
            break;
        }
        variables.skip += variables.limit;
    }
    return results;
}
exports.getUnityReleases = getUnityReleases;
